Dear Juanjo,

I see that your current ECL replaces si:: by ext:
on a few symbols in its version of ASDF.
Should I merge that into the official ASDF,
or should I wait until you make a release of ECL?

If I should merge, here is the attached patch
that you or I can commit into ASDF.

If I should not merge, then considering that differences are easier to track
when ECL's ASDF and the upstream ASDF are kept in synch,
maybe in the future we should make until ECL is released
before we make such changes to even the internal version of ASDF?

I suppose in both cases, I want to add that new
(defmethod bundle-sub-operations ((o monolithic-lib-op) c)
  ...)

—♯ƒ • François-René ÐVB Rideau •Reflection&Cybernethics• http://fare.tunes.org
From 799fc871e1fd38e24e7867217cea32b413fc1dca Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <[email protected]>
Date: Fri, 7 Oct 2011 16:30:06 -0400
Subject: [PATCH] 2.017.10: merge with ECL upstream.
 Beware: there have been package changes in ECL, and
 this ASDF might not work on older versions of ECL...

---
 asdf-ecl.lisp |   12 ++++++++----
 asdf.asd      |    2 +-
 asdf.lisp     |   12 +++++-------
 3 files changed, 14 insertions(+), 12 deletions(-)

diff --git a/asdf-ecl.lisp b/asdf-ecl.lisp
index 37d912e..86185e5 100644
--- a/asdf-ecl.lisp
+++ b/asdf-ecl.lisp
@@ -141,6 +141,10 @@
   (gather-components 'compile-op c
                      :filter-system (and (not (bundle-op-monolithic-p o)) c)
                      :filter-type '(not system)))
+(defmethod bundle-sub-operations ((o monolithic-lib-op) c)
+  (gather-components 'compile-op c
+                     :filter-system nil
+                     :filter-type '(not system)))
 ;;;
 ;;; SHARED LIBRARIES
 ;;;
@@ -415,19 +419,19 @@
 ;;;
 
 (export '(make-build load-fasl-op prebuilt-system))
-(push '("fasb" . si::load-binary) si::*load-hooks*)
+(push '("fasb" . si::load-binary) ext:*load-hooks*)
 
 (defun register-pre-built-system (name)
   (register-system (make-instance 'system :name name :source-file nil)))
 
-(setf si::*module-provider-functions*
-      (loop :for f :in si::*module-provider-functions*
+(setf ext:*module-provider-functions*
+      (loop :for f :in ext:*module-provider-functions*
         :unless (eq f 'module-provide-asdf)
         :collect #'(lambda (name)
                      (let ((l (multiple-value-list (funcall f name))))
                        (and (first l) (register-pre-built-system name))
                        (values-list l)))))
-#+win32 (push '("asd" . si::load-source) si::*load-hooks*)
+#+win32 (push '("asd" . si::load-source) ext:*load-hooks*)
 (pushnew (translate-logical-pathname "SYS:") *central-registry*)
 
 (provide :asdf)
diff --git a/asdf.asd b/asdf.asd
index fd2473f..21d16ae 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.017.9" ;; to be automatically updated by bin/bump-revision
+  :version "2.017.10" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/asdf.lisp b/asdf.lisp
index eb96908..0d7e395 100755
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
 ;;; This is ASDF 2.017.9: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <[email protected]>.
@@ -115,7 +115,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.017.9")
+         (asdf-version "2.017.10")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -679,7 +679,7 @@ pathnames."
 
 (defun* getenv (x)
   (declare (ignorable x))
-  #+(or abcl clisp xcl) (ext:getenv x)
+  #+(or abcl clisp ecl xcl) (ext:getenv x)
   #+allegro (sys:getenv x)
   #+clozure (ccl:getenv x)
   #+(or cmu scl) (cdr (assoc x ext:*environment-list* :test #'string=))
@@ -693,7 +693,6 @@ pathnames."
                (ct:c-string-to-lisp-string buffer1))
       (ct:free buffer)
       (ct:free buffer1)))
-  #+ecl (si:getenv x)
   #+gcl (system:getenv x)
   #+genera nil
   #+lispworks (lispworks:environment-variable x)
@@ -2813,7 +2812,7 @@ output to *VERBOSE-OUT*.  Returns the shell's exit code."
       :input nil :output *verbose-out*))
 
     #+ecl ;; courtesy of Juan Jose Garcia Ripoll
-    (si:system command)
+    (ext:system command)
 
     #+gcl
     (lisp:system command)
@@ -4158,8 +4157,7 @@ with a different configuration, so the configuration would be re-read then."
             #+abcl sys::*module-provider-functions*
             #+clisp ,x
             #+clozure ccl:*module-provider-functions*
-            #+cmu ext:*module-provider-functions*
-            #+ecl si:*module-provider-functions*
+            #+(or cmu ecl) ext:*module-provider-functions*
             #+sbcl sb-ext:*module-provider-functions*))))
 
 
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.017.9: Another System Definition Facility.
+;;; This is ASDF 2.017.10: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
-- 
1.7.2.5

_______________________________________________
asdf-devel mailing list
[email protected]
http://lists.common-lisp.net/cgi-bin/mailman/listinfo/asdf-devel

Reply via email to